#!/usr/bin/env cwl-runner
cwlVersion: v1.2
class: CommandLineTool

label: FastQC - A high throughput sequence QC analysis tool

doc: |
  Original docs: https://www.bioinformatics.babraham.ac.uk/projects/fastqc/

  Run fastqc on raw reads in FASTQ format (single or paired end) or aligned reads in BAM.
  
  This CWL was adapted from: https://github.com/common-workflow-library/bio-cwl-tools/blob/66f620da5b0a11e934a6da83272205a2516bcd91/fastqc/fastqc_1.cwl

hints:
  ResourceRequirement:
    coresMin: 1
    ramMin: 5000
  DockerRequirement:
    dockerPull: quay.io/biocontainers/fastqc:0.11.9--hdfd78af_1
  SoftwareRequirement:
    packages:
      - package: fastqc
        specs: 
          - https://identifiers.org/biotools/fastqc
          - https://identifiers.org/rrid/RRID:SCR_014583
        version: [ "0.11.9" ]

baseCommand: "fastqc"

arguments: 
  - valueFrom: $(runtime.outdir)
    prefix: "-o"
  - valueFrom: "--noextract"

inputs:
  fastq:
    type: File
    inputBinding:
      position: 1
 
outputs:
  fastqc_zip:
    doc: all data e.g. figures
    type: File
    outputBinding:
      glob: "*_fastqc.zip"
  fastqc_html:
    doc: html report showing results from zip
    type: File
    outputBinding:
      glob: "*_fastqc.html"
    

$namespaces:
  edam: https://edamontology.org/
  s: https://schema.org/
$schemas:
  - https://edamontology.org/EDAM_1.25.owl

s:license: https://spdx.org/licenses/GPL-3.0-or-later
